SystemOrganization addCategory: #'Magma seaside'!

!MagmaLocalLocation methodsFor: '*magma seaside' stamp: 'kph 8/11/2006 03:40'!
newSession
	"For local, we have to determine whether the files are already in-use by another
	local-connection.  If they are, create a new session sharing the original's
	repositoryController, Otherwise open the files."

	| sessionClass |
	sessionClass := self sessionClass.
	^ sessionClass connectedSessions
		maDetect: [ :each | each pathName = path ]
		ifFound: [ :foundSession | sessionClass repositoryController: foundSession repositoryController ]
		ifNone: [ sessionClass openLocal: path ]! !

!MagmaLocalLocation methodsFor: '*magma seaside' stamp: 'kph 6/28/2006 04:21'!
repositoryPath

^FileDirectory default fullNameFor: path! !

Object subclass: #WAMagmaDefaultReadStrategy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaDefaultReadStrategy commentStamp: 'kph 9/17/2006 17:38' prior: 0!
Class methods build and set a read strategy for a magmaSession.

The default behaviour is for the root object of the repository to be read and asked to contribute to the MaReadStrategy. For applications that have their own root class it can control the read strategy.

Alternative admin-user selectable (via seaside/config) read strategies may be supplied by providing subclasses. These may override the default behaviour if desired.

The Session readStrategy is updated/rebuilt whenever there is a new seaside session, even when the MagmaSession and the repository is shared among sever seaside sessions.

There is no need to instanciate me.

!

!WAMagmaDefaultReadStrategy class methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 16:57'!
defaultStrategyOn: strategy

"subclasses specialise this method"! !

!WAMagmaDefaultReadStrategy class methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 16:56'!
setStrategyFor: session

| theStrategy |

theStrategy := MaReadStrategy new.

self defaultStrategyOn: theStrategy.
self for: session buildStrategyOn: theStrategy.

session readStrategy: theStrategy.! !

!WAMagmaDefaultReadStrategy methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 17:30'!
askRoot: root toBuildReadStrategyOn: theStrategy


	(root respondsTo: #buildReadStrategyOn:) 
		ifTrue: [ root buildReadSrategyOn: theStrategy ].

! !

!WAMagmaDefaultReadStrategy methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 16:46'!
defaultStrategyOn: strategy

"subclasses specialise this method"! !

!WAMagmaDefaultReadStrategy methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 17:30'!
setStrategyFor: session

| theStrategy |

theStrategy := MaReadStrategy new.

self defaultStrategyOn: theStrategy.
self askRoot: session root toBuildReadStrategyOn: theStrategy.

session readStrategy: theStrategy.

^session! !

WAConfigurationAttribute subclass: #WAMagmaLocationAttribute
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaLocationAttribute methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 10:00'!
accept: aVisitor with: anObject

	^ aVisitor visitMagmaLocationAttribute: self with: anObject! !

!WAMagmaLocationAttribute methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 12:13'!
options

	^ MagmaLocation subclasses! !

!WAConfigurationEditor methodsFor: '*magma seaside' stamp: 'kph 8/14/2006 01:31'!
renderMagmaLocationAttribute: anAttribute on: html

	| location |
	location := configuration valueForAttribute: anAttribute.

	html div id: 'location'; with: [
		html table: [
			location isLocal
				ifTrue: [
					html tableRow: [  
						html tableData id: 'label'; with: 'path:'.
						html tableData: [ html textInput on: #path of: location ]
					]
				] ifFalse: [
					html tableRow: [  
						html tableData id: 'label'; with: 'host'.
						html tableData: [ html textInput on: #host of: location ]
					].
					html tableRow: [  
						html tableData id: 'label'; with: 'port'.
						html tableData: [ html textInput value: location port;
								callback: [:v | location port: v asNumber] ]
					].
				]
		]
	].

	html anchor callback: [ self call: (WAMagmaControlPanel new setLocation: location) ] ; text: '(Magma Control Panel)'.
! !

!WAConfigurationEditor methodsFor: '*magma seaside' stamp: 'kph 6/15/2006 20:33'!
visitMagmaLocationAttribute: anAttribute with: html

	| location |
	location := configuration valueForAttribute: anAttribute. 

	html select 
		list: anAttribute options;
		selected: location class;
		beSubmitOnChange;
		labels: [ :ea | ea name ];
		callback: [ :item | 	(configuration valueAt: #location) class == item
			ifFalse: [ configuration takeValue: item default forAttribute: anAttribute. ]
 		];
		yourself.

	self renderMagmaLocationAttribute: anAttribute on: html.! !

WAComponent subclass: #WAMagmaControlPanel
	instanceVariableNames: 'location magmaSession repositoryControlPanel textInput doneIt'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaControlPanel commentStamp: 'kph 9/4/2006 01:55' prior: 0!
Architecture:

This control panel is available in the magma configuration pane of the seaside/config application. Since the seaside/config application session is not, nor should it be a MagmaSession, this control panel has to manage its own magmaSession.

This control panel anticipates that each application using magma to have its own repository control/status panel. The repository control/status panel is obtained and displayed as a sub-part of the MagmaControlPanel by sending the root object of the current repository #magmaControlPanelOn:  e.g.

magmaSession root magmaControlPanelOn: magmaSession.

If there is not a repository in place then the user is offered the option to create one. It searches for the repository control panels.  These are seaside-components which implement #magmaRootClass and #magmaRootDescription.

[to do]
seasidehosting currently requires the user to manually create the repository directory in the filesystem.
no attempt has been made as yet to ensure that magmaSessions are completely tidied up after using this control panel.
theres is some doubt as to the efficacy of the #done button.


!

!WAMagmaControlPanel class methodsFor: 'as yet unclassified' stamp: 'kph 8/14/2006 12:09'!
canBeRoot

^true! !

!WAMagmaControlPanel class methodsFor: 'as yet unclassified' stamp: 'kph 9/2/2006 01:33'!
initialize
	"self registerAsApplication: 'magma'."! !

!WAMagmaControlPanel class methodsFor: 'as yet unclassified' stamp: 'kph 8/23/2006 19:27'!
newRepository: location

"at present this stats view is available from the configuration editor. The location specified may or may not exist."

^ self new setLocation: location; yourself! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/17/2006 04:26'!
cachedObjectsByClassForSessionId: id

^String streamContents: [ :stream |
	stream nextPutAll: 'cachedObjectCountByClass: '.
	(self magmaSessionWithId: id) cachedObjectCountByClass 
		do: [ :assoc |
			stream nextPutAll: assoc printString.
			stream nextPutAll: ' '; cr.
			
		]
]! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/14/2006 23:21'!
children

^ Array with: repositoryControlPanel! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/4/2006 03:25'!
closeMagmaSession

magmaSession ifNil: [ ^false ].

self location isLocal 
		ifTrue: [ magmaSession disconnectAndClose ]
		ifFalse: [ magmaSession disconnect ].

magmaSession := nil.
repositoryControlPanel := nil.

^true
! !

!WAMagmaControlPanel methodsFor: 'callback actions' stamp: 'kph 8/12/2006 03:18'!
createRepository: repositoryClass

 MagmaRepositoryController create: location path root: repositoryClass new! !

!WAMagmaControlPanel methodsFor: 'callback actions' stamp: 'kph 8/15/2006 05:34'!
deleteRepository

Warning signal: 'Are you sure that you want to delete repository: ', location path.

Warning signal: '(You can still back out) Go ahead and delete repository: ', location path.

(MagmaRepositoryController controllerOpenedOn: location path) ifNotNilDo: [ :mc |  mc close ].

MagmaRepositoryController delete: location path.

magmaSession := nil.! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/4/2006 03:15'!
doIt: aString

doneIt := ( Compiler new evaluate: aString in: nil to: nil ) printString.
! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/24/2006 04:19'!
done

self closeMagmaSession.

self answer! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/17/2006 04:08'!
exploreRepositoryOfSessionId: id

| ms |

ms := self magmaSessionWithId: id.

 [ { ms. ms root } explore ] fork! !

!WAMagmaControlPanel methodsFor: 'accessing' stamp: 'kph 9/5/2006 23:43'!
hasScriptaculous
	Smalltalk at: #SULibrary ifPresent: [ :class |
		^ self session application libraries
			includes: class ].
	^ false! !

!WAMagmaControlPanel methodsFor: 'accessing' stamp: 'kph 8/14/2006 12:17'!
location

^ location! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/24/2006 04:00'!
magmaConnect: aBlock ifAbsent: notThereBlock

[
self magmaSession commitAndBegin.

aBlock value.

] 
	on: MagmaEnvironmentError 
	do: notThereBlock.  ! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/15/2006 02:40'!
magmaSession

^magmaSession ifNil: [ self openMagmaSession ].
! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/17/2006 04:06'!
magmaSessionWithId: id

^MagmaSession allInstances detect: [ :ms | ms id = id ]! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/24/2006 03:54'!
openMagmaSession

	
	magmaSession := self location isLocal 
		ifTrue: [ MagmaSession openLocal: self location path ]
		ifFalse: [ MagmaSession host: self location host port: self location port ].

	magmaSession connectAs: 'seaside' ; begin.

	 repositoryControlPanel := [ magmaSession root magmaControlPanelOn: magmaSession ] on: Error do: [ nil ].

^magmaSession

! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/24/2006 02:38'!
presentCreateRepositoryOptionsOn: html

	html heading level: 3; with: [ html text:  'options:'].
		html text: 'You may create a repository with one of the following root objects for this application.'.
		html div class: 'repositories'; with: [ 
			html table: [
				((SystemNavigation default allImplementorsOf: #magmaRootClass) collect: [ :m | m actualClass soleInstance ])				
				do: [ :c | 
						html tableRow: [ 
					 			html tableData: [ html bold:  c magmaRootClass name ].
								html tableData: [ html text:   c magmaRootDescription ].
								html tableData: [ html submitButton callback: [ self createRepository: c magmaRootClass ]; text: 'Create'. ]
						] 
					]
				]
			].! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/17/2006 04:20'!
renderAllRepositoryStatsOn: html

| |

html orderedList: [ 
	MagmaRepositoryController openControllers do: [ :mrc |
		
		html listItem: [
			html bold: mrc objectCount asString.
			html text: ' objects in repository: '.
			 
			html bold: mrc directory pathName.
			html orderedList: [
				mrc repository sessions do: [ :client |
					html listItem: [
						html bold: 'session id: '.
						html text: client sessionId printString.
						html bold: ' cached objects: '.
						html anchor callback: [ self inform: (self cachedObjectsByClassForSessionId: client sessionId) ]; text: (self magmaSessionWithId: client sessionId) cachedObjectCount.
						html text: ' '.
						html small: [ html anchor callback: [ self exploreRepositoryOfSessionId: client sessionId ]; text: '(explore)' ].

					].
				]	 
			].			
				"html tableData: [ html text: c numberOfConnectedClients asString ]."
		].
	].
]
	 
 
 


 ! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/4/2006 01:44'!
renderContentOn: html

html form: [

	self renderThisRepositoryStatusOn: html.

	html heading level: 2; with: [ html text: 'Magma Status'].

	self renderAllRepositoryStatsOn: html.

	self renderUtilsOn: html.

].! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/4/2006 02:01'!
renderEvaluatorOn: html
	self
		renderLabel: 'Text-Input'
		control: [ :fid :mid |
			html textInput
				value: textInput;
				callback: [ :value | textInput := value ].
			html space.
			html submitButton
				onClick: (html updater
					id: mid;
					triggerForm: fid;
					callback: [ :r | r render: textInput ];
					return: false);
				text: 'Submit' ]
		model: textInput
		on: html! !

!WAMagmaControlPanel methodsFor: 'accessing' stamp: 'kph 8/10/2006 16:38'!
rendererClass
        ^ WARenderCanvas ! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/4/2006 02:13'!
renderLabel: aString control: aBlock model: anObject on: html
	| fid mid |
	fid := mid := nil.
	html div class: 'row'; with: [
		html div class: 'label'; with: aString.
		html div class: 'control'; with: [
			html form
				id: (fid := html nextId);
				with: [ aBlock value: fid value: (mid := html nextId) ] ].
		html div class: 'model'; id: mid; with: anObject.
		html div class: 'clear' ]! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/12/2006 03:37'!
renderLocalPathOn: html

html bold: 'Repository path setting: '.
html text: location path.


! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/2/2006 01:36'!
renderMagmaError: ex on: html

	html break.
	html bold: 'Error: ', ex messageText.
	html break.
	self location isLocal 
		ifTrue: [ self renderPresentCreateRepositoryOptionsOn: html	] 
		ifFalse: [ html text: 'Remote repository not available' ].! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/2/2006 01:36'!
renderPresentCreateRepositoryOptionsOn: html

	html heading level: 3; with: [ html text:  'options:'].
		html text: 'You may create a repository with one of the following root objects for this application.'.
		html div class: 'repositories'; with: [ 
			html table: [
				((SystemNavigation default allImplementorsOf: #magmaRootClass) collect: [ :m | m actualClass soleInstance ])				
				do: [ :c | 
						html tableRow: [ 
					 			html tableData: [ html bold:  c magmaRootClass name ].
								html tableData: [ html text:   c magmaRootDescription ].
								html tableData: [ html submitButton callback: [ self createRepository: c magmaRootClass ]; text: 'Create'. ]
						] 
					]
				]
			].! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/12/2006 03:38'!
renderRemoteHostOn: html

html bold: 'Repository host: '.
html text: location host , ':' , location port.
! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/17/2006 04:00'!
renderRepositoryOnlineOn: html

	self location isLocal ifTrue: [  html text: '   '. 
		html small: [ html anchor callback: [ self deleteRepository ];text: '(delete)' ]].

	html break.
	html bold: 'Session Id: '.
	html text: magmaSession id.
	html break.
	html bold: 'Cached Object Count: '.
	html text: magmaSession cachedObjectCount.

	html break.
	html bold: 'Root Object: '.
	html text: magmaSession root asString.
	html horizontalRule.
	html render: repositoryControlPanel.
	html horizontalRule.
! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/4/2006 03:16'!
renderServerDoItOn: html
	self
		renderLabel: 'Server Do It'
		control: [ :fid :mid |
			html textInput
				value: textInput;
				callback: [ :value | self doIt: (textInput := value).  ].
			html space.
			html submitButton
				onClick: (html updater
					id: mid;
					triggerForm: fid;
					callback: [ :r | r render:textInput ];
					return: false);
				text: 'do it' ]
		model: doneIt 
		on: html! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/1/2006 00:57'!
renderTestingSeasideHostingOn: html.

html anchor callback: [ (FileDirectory on: (FileDirectory default fullPathFor: 'resources')) exists ] ; text: 'check exists'.! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/4/2006 01:44'!
renderThisRepositoryStatusOn: html

	self location ifNil: [ ^self ].

	html heading level: 2; with: [ html text: 'This Repository:'].

	self location isLocal ifTrue: [ self renderLocalPathOn: html ]
						ifFalse: [ self renderRemoteHostOn: html ].
		
	self magmaConnect: [ self renderRepositoryOnlineOn: html
			] ifAbsent: [ :ex | self renderMagmaError: ex on: html ].
	
	html break.
	html submitButton on: #done of: self.

	html horizontalRule.! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/17/2006 04:09'!
renderUtilsOn: html

html horizontalRule.

html bold: 'Miscellaneous Utilities: '.

html break.

html submitButton callback: [ MagmaSession cleanUp ]; text: 'MagmaSession cleanUp'.

html break.

html submitButton callback: [ self saveImageSnapshot ]; text: 'Save Server Image'.

self hasScriptaculous ifTrue: [ html horizontalRule.  self renderServerDoItOn: html ].! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 9/4/2006 01:43'!
saveImageSnapshot

 SmalltalkImage current snapshot: true andQuit: false.! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/10/2006 14:04'!
setLocation: l

location := l! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/11/2006 14:16'!
style

^ 

'
div.repositories table td {
	border: 1px solid #888;

'! !

WASystemConfiguration subclass: #WAMagmaConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'mmb 12/5/2005 09:17'!
ancestors

	^ Array with: (WARenderLoopConfiguration new)! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 16:20'!
attributes
    "Return the attributes specific to this configuration"

	^ Array with: (WAMagmaLocationAttribute key: #location group: #magma)
			 with: ((WAListAttribute key: #readStrategy group: #magma)
						options: self readStrategyClasses; yourself ).
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 11:44'!
location

	^ MagmaLocalLocation default
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 17:01'!
readStrategy 

^ WAMagmaDefaultReadStrategy
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 17:01'!
readStrategyClasses 

^ WAMagmaDefaultReadStrategy withAllSubclasses
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 11:35'!
repositoryPath

	^ 'store'
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 11:24'!
sessionClass

	^ WAMagmaSession! !

!MagmaLocation methodsFor: '*magma seaside' stamp: 'kph 9/9/2006 03:21'!
newSessionAs: userName

 ^ self newSession connectAs: userName; yourself! !

WASession subclass: #WAMagmaSession
	instanceVariableNames: 'magmaSession'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaSession commentStamp: 'kph 9/17/2006 17:35' prior: 0!
The Session readStrategy is updated/rebuilt whenever there is a new seaside session, even when the MagmaSession and the repository is shared among sever seaside sessions.!

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'kph 9/9/2006 17:41'!
commit: aBlock

	self magmaSession commit: aBlock
! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 12:58'!
expire

	super expire.
	magmaSession ifNotNil: [ magmaSession disconnect. magmaSession := nil ]! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'kph 9/9/2006 03:15'!
location 

^self application preferenceAt: #location.
! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 17:16'!
magmaSession

^ magmaSession ifNil: [ 	magmaSession := self obtainMagmaSession ]! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 17:16'!
obtainMagmaSession

^self readStrategyClass setStrategyFor: 
			(self location newSessionAs: 'seaside').! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 16:56'!
readStrategyClass

 ^ self application preferenceAt: #readStrategy! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'kph 8/11/2006 03:41'!
repositoryPath
	"This is a convenience method to get the repository directory path from Seaside"

	^ self application preferenceAt: #repositoryPath! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 12:52'!
root

	^ self magmaSession root
! !

WAMagmaSession subclass: #WAMagmaSharedSession
	instanceVariableNames: ''
	classVariableNames: 'MagmaSessions'
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaSharedSession commentStamp: 'kph 9/17/2006 02:42' prior: 0!
WAMagmaSharedSession keeps one session per repository, and this is provided to each Seaside Session. i.e. each seaside session can access the database but needs to be aware that it may be sharing its view of the model with other seaside sessions.

Pier has a model locking mechanism in place to prevent concurrent edits, and so will perform better with WAMagmaSharedSession than with a standard WAMagmaSession Since sharing the magma session avoids the overhead of connecting to the database at the beginning of every user session.

Rules for use:
Do not abort, you may ruin someone else's transaction.
Ensure that commits are negotiated amongst the sharing users via locking. If one seaside session commits: while another is in mid transaction their changes will be lost. 
To use a shared session there should be one data model that manages commits: and aborts on behalf of all of its seaside session clients.
!

!WAMagmaSharedSession class methodsFor: 'class initialization' stamp: 'kph 9/9/2006 03:32'!
initialize

MagmaSessions := Dictionary new.! !

!WAMagmaSharedSession methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 17:13'!
expire

	super expire.
	magmaSession ifNotNil: [ magmaSession := nil ]! !

!WAMagmaSharedSession methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 17:14'!
magmaAbortOnRequest.

"dont for a shared session"! !

!WAMagmaSharedSession methodsFor: 'as yet unclassified' stamp: 'kph 9/17/2006 17:19'!
obtainMagmaSession

| ms |

ms := MagmaSessions at: (self location) ifAbsent: [ nil ].

(ms nil or: [ ms isOpen not ]) 
	ifFalse: [ ms := MagmaSessions at: self location put: super obtainMagmaSession ].

^self readStrategyClass setStrategyFor: ms! !

!UnixFileDirectory methodsFor: '*magma seaside' stamp: 'kph 9/1/2006 01:38'!
directoryExists: filenameOrPath
    "Handles the special case of testing for the root dir: there isn't a
    possibility to express the root dir as full pathname like '/foo'."

    ^ filenameOrPath = '/'
        or: [ filenameOrPath = self class default pathName
        or: [ super directoryExists: filenameOrPath ] ]
! !

!MagmaRepositoryController class methodsFor: '*magma seaside' stamp: 'kph 9/1/2006 02:08'!
controllerOpenedOn: pathName

| path | 

path := (self fd: pathName) pathName.

	^ OpenControllers
		maDetect: [ : each | each directory pathName = path ]
		ifFound: [ : foundController | foundController ensureOpen ]
		ifNone: [ nil ]! !

!MagmaRepositoryController class methodsFor: '*magma seaside' stamp: 'kph 9/1/2006 01:53'!
create: localNameOrFullyQualifiedPathString

	"Creates a repository with an initial root of nil.  I #assureExistence of the localNameOrFullyQualifiedPathString."

	| fd |

	fd := self fd: localNameOrFullyQualifiedPathString. 
	self validateCanCreateIn: fd.
	self new createRepositoryAt: fd! !

!MagmaRepositoryController class methodsFor: '*magma seaside' stamp: 'kph 9/1/2006 01:57'!
delete: localNameOrFullyQualifiedPathString
	"Delete the just the files in fullyQualifiedPathString that are part of the Magma repository that resides there."
	| fd |

	fd := self fd: localNameOrFullyQualifiedPathString.

	(fd exists and: [ fd fileExists: MaObjectFiler objectsFilename ]) ifFalse:
		[ (MagmaNotification new messageText: fd pathName , ' does not exist, nothing to delete.') signal.
		^ self ].
	(self filesFor: fd pathName), { (MaRecoveryManager commitPackagesFilename) } do:
		[ : each |
			fd deleteFileNamed: each asString
			ifAbsent: [ MagmaNotification signal: 'Couldn''t find ' , each asString ] ]! !

!MagmaRepositoryController class methodsFor: '*magma seaside' stamp: 'kph 9/1/2006 01:52'!
fd: path

^FileDirectory on: (FileDirectory default fullNameFor: path).

	 ! !

!MagmaRepositoryController class methodsFor: '*magma seaside' stamp: 'kph 8/24/2006 22:21'!
openControllers

^OpenControllers! !

!MagmaRepositoryController class methodsFor: '*magma seaside' stamp: 'kph 9/1/2006 02:08'!
openedOn: pathString

	| existingController  |
	^ (existingController := self controllerOpenedOn:  pathString)
		ifNil: [ self open: pathString ]
		ifNotNil: [ existingController ].! !

!MagmaRepositoryController class methodsFor: '*magma seaside' stamp: 'kph 9/1/2006 01:56'!
open:pathString

	^ self new open: (self fd: pathString)! !
WAMagmaControlPanel initialize!
WAMagmaSharedSession initialize!
